MCALF visualisation
*******************

This sub-package contains:

* Functions to plot the input spectrum and the fitted
  model.
* Functions to plot the spatial distribution and their
  general profile.
* Functions to plot the velocities calculated for a
  spectral imaging scan.

.. automodapi:: mcalf.visualisation
